Module: MiniRacer
- Defined in:
- lib/mini_racer/shared.rb,
lib/mini_racer.rb,
lib/mini_racer.rb,
lib/mini_racer/version.rb,
lib/mini_racer/truffleruby.rb,
ext/mini_racer_loader/mini_racer_loader.c,
ext/mini_racer_extension/mini_racer_extension.c
Overview
This code used to be shared in lib/mini_racer.rb but was moved to the extension with github.com/rubyjs/mini_racer/pull/325. So now this is effectively duplicate logic with C/C++ code. Maybe one day it can be actually shared again between both backends.
Defined Under Namespace
Modules: Loader Classes: Binary, Context, ContextDisposedError, Error, EvalError, FailedV8Conversion, InternalError, Isolate, JavaScriptFunction, ParseError, Platform, PlatformAlreadyInitialized, RuntimeError, ScriptError, ScriptTerminatedError, Snapshot, SnapshotError, V8OutOfMemoryError
Constant Summary collapse
- MARSHAL_STACKDEPTH_DEFAULT =
2**9-2
- MARSHAL_STACKDEPTH_MAX_VALUE =
2**10-2
- VERSION =
"0.21.0"- LIBV8_NODE_VERSION =
"~> 24.12.0.1"